@@ -6,13 +6,14 @@ test_that("Checking output format", {
 
 test_that("Checking output format, one site", {
   skip_on_cran()
-  result <- anlzMWRmap(res = resdat, param = 'DO', acc = accdat, sit = sitdat, warn = FALSE, site = 'ABT-026', addwater = "low", maptype = 'terrain')
+  result <- anlzMWRmap(res = resdat, param = 'DO', acc = accdat, sit = sitdat, warn = FALSE, site = 'ABT-026', addwater = NULL, maptype = 'terrain')
   expect_s3_class(result, 'ggplot')
 })
 
 test_that("Checking warning output", {
   skip_on_cran()
-  expect_warning(anlzMWRmap(res = resdat, param = 'E.coli', acc = accdat, sit = sitdat, warn = TRUE))
+  sitdatchk <- sitdat[!sitdat$`Monitoring Location ID` == 'ABT-077', ]
+  expect_warning(anlzMWRmap(res = resdat, param = 'E.coli', acc = accdat, sit = sitdatchk, warn = TRUE, addwater = NULL))
 })
 
 test_that("Checking error output no sites to map", {
@@ -21,13 +22,13 @@ test_that("Checking error output no sites to map", {
 
 test_that("Checking output format, no scale bar or north arrow", {
   skip_on_cran()
-  result <- anlzMWRmap(res = resdat, param = 'DO', acc = accdat, sit = sitdat, warn = FALSE, northloc = NULL, scaleloc = NULL)
+  result <- anlzMWRmap(res = resdat, param = 'DO', acc = accdat, sit = sitdat, warn = FALSE, northloc = NULL, scaleloc = NULL, addwater = NULL)
   expect_s3_class(result, 'ggplot')
 })
 
 test_that("Checking output format, no label repel", {
   skip_on_cran()
-  result <- anlzMWRmap(res = resdat, param = 'DO', acc = accdat, sit = sitdat, warn = FALSE, repel = FALSE)
+  result <- anlzMWRmap(res = resdat, param = 'DO', acc = accdat, sit = sitdat, warn = FALSE, repel = FALSE, addwater = NULL)
   expect_s3_class(result, 'ggplot')
 })
 
@@ -36,7 +37,7 @@ test_that("Checking error for addwater input", {
 })
 
 test_that("Checking missing spatial data", {
-  sitdatchk <- sitdat[-4, ]
+  sitdatchk <- sitdat[!sitdat$`Monitoring Location ID` == 'ABT-144', ]
   expect_error(anlzMWRmap(res = resdat, param = 'DO', acc = accdat, sit = sitdatchk, site = 'ABT-144'))
 })
 
