@@ -31,4 +31,11 @@ test_that("Checking output warning if missing completeness data and format type
   chk <- frecomdat
   chk$`% Completeness`[8] <- NA
   expect_warning(tabMWRacc(respth, accpth, chk, runchk = F, warn = T, type = 'percent'))
+})
+
+test_that("Checking error if no QC records or reference values", {
+  chk <- readMWRacc(accpth, runchk = F, warn = F) %>% 
+    mutate_at(vars(matches('Duplicate|Blank|Accuracy')), function(x) NA)
+  
+  expect_error(tabMWRacc(respth, chk, frecompth, runchk = F, warn = T, type = 'percent'))
 })
\ No newline at end of file
